<?php
/**
 * ReduxFramework Sample Config File
 * For full documentation, please visit: http://docs.reduxframework.com/
 */	

if ( ! class_exists( 'Redux' ) ) {
	return;
}

// This is your option name where all the Redux data is stored.
$befold_redux_opt_name = "redux_demo";

// This line is only for altering the demo. Can be easily removed.
$befold_redux_opt_name = apply_filters( 'befold_redux_demo/befold_opt_name', $befold_redux_opt_name );

/*
 *
 * --> Used within different fields. Simply examples. Search for ACTUAL DECLARATION for field examples
 *
 */

$befold_sampleHTML = '';
if ( file_exists( dirname( __FILE__ ) . '/info-html.html' ) ) {
	Redux_Functions::initWpFilesystem();

	global $wp_filesystem;

	$befold_sampleHTML = $wp_filesystem->get_contents( dirname( __FILE__ ) . '/info-html.html' );
}

// Background Patterns Reader
$befold_sample_patterns_path = ReduxFramework::$_dir . '../sample/patterns/';
$befold_sample_patterns_url  = ReduxFramework::$_url . '../sample/patterns/';
$befold_sample_patterns      = array();

if ( is_dir( $befold_sample_patterns_path ) ) {

	if ( $befold_sample_patterns_dir = opendir( $befold_sample_patterns_path ) ) {
		$befold_sample_patterns = array();

		while ( ( $befold_sample_patterns_file = readdir( $befold_sample_patterns_dir ) ) !== false ) {

			if ( stristr( $befold_sample_patterns_file, '.png' ) !== false || stristr( $befold_sample_patterns_file, '.jpg' ) !== false ) {
				$befold_name              = explode( '.', $befold_sample_patterns_file );
				$befold_name              = str_replace( '.' . end( $befold_name ), '', $befold_sample_patterns_file );
				$befold_sample_patterns[] = array(
					'alt' => $befold_name,
					'img' => $befold_sample_patterns_url . $befold_sample_patterns_file
				);
			}
		}
	}
}

/**
 * ---> SET ARGUMENTS
 * All the possible arguments for Redux.
 * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
 * */

$befold_redux_theme = wp_get_theme(); // For use with some settings. Not necessary.

$befold_redux_args = array(
	// TYPICAL -> Change these values as you need/desire
	'opt_name'             => $befold_redux_opt_name,
	// This is where your data is stored in the database and also becomes your global variable name.
	'display_name'         => $befold_redux_theme->get( 'Name' ),
	// Name that appears at the top of your panel
	'display_version'      => $befold_redux_theme->get( 'Version' ),
	// Version that appears at the top of your panel
	'menu_type'            => 'menu',
	//Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
	'allow_sub_menu'       => true,
	// Show the sections below the admin menu item or not
	'menu_title'           => __( 'Theme Options', 'befold' ),
	'page_title'           => __( 'Theme Options', 'befold' ),
	// You will need to generate a Google API key to use this feature.
	// Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
	'google_api_key'       => '',
	// Set it you want google fonts to update weekly. A google_api_key value is required.
	'google_update_weekly' => false,
	// Must be defined to add google fonts to the typography module
	'async_typography'     => false,
	// Use a asynchronous font on the front end or font string
	//'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
	'admin_bar'            => true,
	// Show the panel pages on the admin bar
	'admin_bar_icon'       => 'dashicons-portfolio',
	// Choose an icon for the admin bar menu
	'admin_bar_priority'   => 50,
	// Choose an priority for the admin bar menu
	'global_variable'      => '',
	// Set a different name for your global variable other than the opt_name
	'dev_mode'             => true,
	// Show the time the page took to load, etc
	'update_notice'        => true,
	// If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
	'customizer'           => true,
	// Enable basic customizer support
	//'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
	//'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

	// OPTIONAL -> Give you extra features
	'page_priority'        => null,
	// Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
	'page_parent'          => 'themes.php',
	// For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
	'page_permissions'     => 'manage_options',
	// Permissions needed to access the options panel.
	'menu_icon'            => '',
	// Specify a custom URL to an icon
	'last_tab'             => '',
	// Force your panel to always open to a specific tab (by id)
	'page_icon'            => 'icon-themes',
	// Icon displayed in the admin panel next to your menu_title
	'page_slug'            => 'redux_demo',
	// Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
	'save_defaults'        => true,
	// On load save the defaults to DB before user clicks save or not
	'default_show'         => false,
	// If true, shows the default value next to each field that is not the default value.
	'default_mark'         => '',
	// What to print by the field's title if the value shown is default. Suggested: *
	'show_import_export'   => true,
	// Shows the Import/Export panel when not used as a field.

	// CAREFUL -> These options are for advanced use only
	'transient_time'       => 60 * MINUTE_IN_SECONDS,
	'output'               => true,
	// Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
	'output_tag'           => true,
	// Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
	// 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

	// FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
	'database'             => '',
	// possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
	'use_cdn'              => true,
	// If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

	// HINTS
	'hints'                => array(
		'icon'          => 'el el-question-sign',
		'icon_position' => 'right',
		'icon_color'    => 'lightgray',
		'icon_size'     => 'normal',
		'tip_style'     => array(
			'color'   => 'red',
			'shadow'  => true,
			'rounded' => false,
			'style'   => '',
		),
		'tip_position'  => array(
			'my' => 'top left',
			'at' => 'bottom right',
		),
		'tip_effect'    => array(
			'show' => array(
				'effect'   => 'slide',
				'duration' => '500',
				'event'    => 'mouseover',
			),
			'hide' => array(
				'effect'   => 'slide',
				'duration' => '500',
				'event'    => 'click mouseleave',
			),
		),
	)
);

// ADMIN BAR LINKS -> Setup custom links in the admin bar menu as external items.
$befold_redux_args['admin_bar_links'][] = array(
	'id'    => 'redux-docs',
	'href'  => 'http://docs.reduxframework.com/',
	'title' => __( 'Documentation', 'befold' ),
);

$befold_redux_args['admin_bar_links'][] = array(
	//'id'    => 'redux-support',
	'href'  => 'https://github.com/ReduxFramework/redux-framework/issues',
	'title' => __( 'Support', 'befold' ),
);

$befold_redux_args['admin_bar_links'][] = array(
	'id'    => 'redux-extensions',
	'href'  => 'reduxframework.com/extensions',
	'title' => __( 'Extensions', 'befold' ),
);

// SOCIAL ICONS -> Setup custom links in the footer for quick links in your panel footer icons.
$befold_redux_args['share_icons'][] = array(
	'url'   => 'https://github.com/ReduxFramework/ReduxFramework',
	'title' => __( 'Visit us on GitHub', 'befold' ),
	'icon'  => 'el el-github'
	//'img'   => '', // You can use icon OR img. IMG needs to be a full URL.
);
$befold_redux_args['share_icons'][] = array(
	'url'   => 'https://www.facebook.com/pages/Redux-Framework/243141545850368',
	'title' => __( 'Like us on Facebook', 'befold' ),
	'icon'  => 'el el-facebook'
);
$befold_redux_args['share_icons'][] = array(
	'url'   => 'http://twitter.com/reduxframework',
	'title' => __( 'Follow us on Twitter', 'befold' ),
	'icon'  => 'el el-twitter'
);
$befold_redux_args['share_icons'][] = array(
	'url'   => 'http://www.linkedin.com/company/redux-framework',
	'title' => __( 'Find us on LinkedIn', 'befold' ),
	'icon'  => 'el el-linkedin'
);

// Panel Intro text -> before the form
if ( ! isset( $befold_redux_args['global_variable'] ) || $befold_redux_args['global_variable'] !== false ) {
	if ( ! empty( $befold_redux_args['global_variable'] ) ) {
		$befold_v = $befold_redux_args['global_variable'];
	} else {
		$befold_v = str_replace( '-', '_', $befold_redux_args['opt_name'] );
	}
	$befold_redux_args['intro_text'] = sprintf( __( '<p>Did you know that Redux sets a global variable for you? To access any of your saved options from within your code you can use your global variable: <strong>$%1$s</strong></p>', 'befold' ), $befold_v );
} else {
	$befold_redux_args['intro_text'] = __( '<p>This text is displayed above the options panel. It isn\'t required, but more info is always better! The intro_text field accepts all HTML.</p>', 'befold' );
}

// Add content after the form.
$befold_redux_args['footer_text'] = __( '<p>This text is displayed below the options panel. It isn\'t required, but more info is always better! The footer_text field accepts all HTML.</p>', 'befold' );

Redux::setArgs( $befold_redux_opt_name, $befold_redux_args );

/*
 * ---> END ARGUMENTS
 */

/*
 *
 * ---> START SECTIONS
 *
 */

/*
	As of Redux 3.5+, there is an extensive API. This API can be used in a mix/match mode allowing for
*/

// -> START Basic Fields
$befold_redux_permalink_url = '<a href="'. admin_url() .'options-reading.php" target="_blank">here</a>';
/*  General Panel Start  */
Redux::setSection( $befold_redux_opt_name, array(
	'title'            => __( 'General', 'befold' ),
	'id'               => 'site_general',
	'desc'             => __( 'These are really basic fields!', 'befold' ),
	'customizer_width' => '400px',
	'icon'             => 'el el-user',
	'fields'           => array(
		array(
			'id'       => 'general_sticky_menu',
			'type'     => 'checkbox',
			'title'    => __( 'Enable Sticky Menu?', 'befold' ),
			'subtitle' => '',
			'desc'     => __( 'If enable, the menu will be accessible from anywhere without having to scroll.', 'befold' ),
			'default'  => '',
		),
		 array(
			'id'       => 'general_go_to_top',
			'type'     => 'checkbox',
			'title'    => __( 'Enable Go to Top Button?', 'befold' ),
			'subtitle' => '',
			'desc'     => '',
			'default'  => '',
		),
		
	)
) ); 
/* General Panel End */

/* Site Blog Panel Start */
Redux::setSection( $befold_redux_opt_name, array(
	'title'      => __( 'Blog Page',  'befold' ),
	'icon'      => 'el el-book',
	'id'		=> 'site_blog_page',
	'customizer_width' => '400px',
	'desc' 		=> __( 'Here you can customize your blog pages.', 'befold' ),
	'validate_callback' => 'befold_is_blog_page_redux',
	'fields'          => array(
		array(
			'id'              => 'blog_page_header_bg',
			'type'            => 'background',
			'title'           => esc_html__( 'Header Image', 'befold' ),
			'output'    => array('.page-header'),
			'default'         => array(
				'background-color'  => '#f87c57', 
				'background-position'  => 'center center', 
				'background-size'  => 'cover', 
				'background-repeat' => 'no-repeat',
				'background-attachment' => 'inherit',
				'background-image' => get_template_directory_uri() . '/assets/images/header_bg.jpg'
			),
		),
	)
)   );
/* Site Blog Panel end */	
/* Site Footer Panel Start */

Redux::setSection( $befold_redux_opt_name, array(
'title'            => __( 'Site Footer', 'befold' ),
'id'               => 'site_footer',
'desc'             => '',
'customizer_width' => '400px',
'icon'             => 'el el-photo',
'fields'           => array(
	array(
		'id'       => 'footer_copyright',
		'type'     => 'editor',
		'title'    => __( 'Copyright Information', 'befold' ),
		'subtitle' => '',
		'desc'     => __( 'Want to remove the theme byline? See section "Upgrade" for more information.', 'befold' ),
		'default'  =>'',
		  'args'    => array(
			'wpautop'       => true,
			'media_buttons' => true,
			'textarea_rows' => 5,
			'teeny'         => false,
			'quicktags'     => true,
		)
	),
	array(
		'id'       => 'footer_site_title',
		'type'     => 'checkbox',
		'title'    => esc_html__( 'Show Site Title?', 'befold' ),
		'desc'     => '',
		'default'  => '',
	)	
)
)	);

/* Site Footer Panel End */
	

if ( file_exists( dirname( __FILE__ ) . '/../README.md' ) ) {
	$befold_section = array(
		'icon'   => 'el el-list-alt',
		'title'  => __( 'Documentation', 'befold' ),
		'fields' => array(
			array(
				'id'       => '17',
				'type'     => 'raw',
				'markdown' => true,
				'content_path' => dirname( __FILE__ ) . '/../README.md', // FULL PATH, not relative please
			),
		),
	);
	Redux::setSection( $befold_redux_opt_name, $befold_section );
}
/*
 * <--- END SECTIONS
 */

/*
 *
 * YOU MUST PREFIX THE FUNCTIONS BELOW AND ACTION FUNCTION CALLS OR ANY OTHER CONFIG MAY OVERRIDE YOUR CODE.
 *
 */

/*
*
* --> Action hook examples
*
*/

/**
 * This is a test function that will let you see when the compiler hook occurs.
 * It only runs if a field    set with compiler=>true is changed.
 * */
if ( ! function_exists( 'befold_compiler_action' ) ) {
	function befold_compiler_action( $options, $css, $changed_values ) {
		echo '<h1>The compiler hook has run!</h1>';
	}
}

/**
 * Custom function for the callback validation referenced above
 * */
if ( ! function_exists( 'befold_redux_validate_callback_function' ) ) {
	function befold_redux_validate_callback_function( $field, $value, $existing_value ) {
		$error   = false;
		$warning = false;

		//do your validation
		if ( $value == 1 ) {
			$error = true;
			$value = $existing_value;
		} elseif ( $value == 2 ) {
			$warning = true;
			$value   = $existing_value;
		}

		$return['value'] = $value;

		if ( $error == true ) {
			$field['msg']    = 'your custom error message';
			$return['error'] = $field;
		}

		if ( $warning == true ) {
			$field['msg']      = 'your custom warning message';
			$return['warning'] = $field;
		}

		return $return;
	}
}

/**
 * Custom function for the callback referenced above
 */
if ( ! function_exists( 'befold_redux_my_custom_field' ) ) {
	function befold_redux_my_custom_field( $field, $value ) {
		print_r( $field );
		echo '<br/>';
		print_r( $value );
	}
}

/**
 * Custom function for filtering the sections array. Good for child themes to override or add to the sections.
 * Simply include this function in the child themes functions.php file.
 * NOTE: the defined constants for URLs, and directories will NOT be available at this point in a child theme,
 * so you must use get_template_directory_uri() if you want to use any of the built in icons
 * */
if ( ! function_exists( 'befold_dynamic_section' ) ) {
	function befold_dynamic_section($befold_sections ) {
		
		$befold_sections[] = array(
			'title'  => __( 'Section via hook', 'befold' ),
			'desc'   => __( '<p class="description">This is a section created by adding a filter to the sections array. Can be used by child themes to add/remove sections from the options.</p>', 'befold' ),
			'icon'   => 'el el-paper-clip',
			// Leave this as a blank section, no options just some intro text set above.
			'fields' => array()
		);

		return $befold_sections;
	}
}

/**
 * Filter hook for filtering the args. Good for child themes to override or add to the args array. Can also be used in other functions.
 * */
if ( ! function_exists( 'befold_change_arguments' ) ) {
	function befold_change_arguments( $befold_redux_args ) {
		return $befold_redux_args;
	}
}

/**
 * Filter hook for filtering the default value of any given field. Very useful in development mode.
 * */
if ( ! function_exists( 'befold_change_defaults' ) ) {
	function befold_change_defaults( $defaults ) {
		$defaults['str_replace'] = 'Testing filter hook!';

		return $defaults;
	}
}

/**
 * Removes the demo link and the notice of integrated demo from the redux-framework plugin
 */
if ( ! function_exists( 'befold_remove_demo' ) ) {
	function befold_remove_demo() {
		// Used to hide the demo mode link from the plugin page. Only used when Redux is a plugin.
		if ( class_exists( 'ReduxFrameworkPlugin' ) ) {
			remove_filter( 'plugin_row_meta', array(
				ReduxFrameworkPlugin::instance(),
				'plugin_metalinks'
			), null, 2 );

			// Used to hide the activation notice informing users of the demo panel. Only used when Redux is a plugin.
			remove_action( 'admin_notices', array( ReduxFrameworkPlugin::instance(), 'admin_notices' ) );
		}
	}
}